@@ -73,7 +73,7 @@ def loop_input_port(actor: Actor, input_ports: list, state_utils: FlowStateUtils
                 # 获取消息payload
                 content = msg_object.get_payload()
                 if isinstance(actor, SinkActor):
-                    print('-----sink算子')
+                    # logger.info('-----sink算子')
                     actor.write(content, input_port)
                 elif isinstance(actor, ComputeActor):
                     print('----计算算子')
@@ -166,7 +166,6 @@ def actor_running(current_actor_state=None) -> None:
 def get_actor_final_state(actor_name: str, state_utils: FlowStateUtils) -> str:
     # 查询actor的状态
     state = state_utils.get_actor_final_state(actor_name)
-    print(actor_name+'的状态：'+state)
     return state
 
 
@@ -234,24 +233,28 @@ def get_actor_output_ports(actor: Actor, actor_desc: json) -> list:
 '''
 获取actor的params
 '''
-
+system_parameters = ["core_num", "partition", "parallel_num", "ntask"]
 
 def get_actor_params(actor: Actor, actor_desc: json) -> Args:
     params_json = dict_utils.get_property_value(actor_desc, 'parameters', [])
     args = Args()
     for param in params_json:
-        # param的类型
+        # type
         param_type = param.get('type')
+        # param的类型
+        param_variable = param.get('variable')
         # param的名称
         param_name = param.get('name')
         # param的值
         param_value = param.get('value')
+        # description
+        param_description = param.get('description')
         # port依赖的上游actor
         module = str(config.PARAM_PATH)
         param_module = importlib.import_module(module)
         param_class = getattr(param_module, param_type)
-        param = param_class(param_name, param_value)
-        setattr(args, param_name, param)
+        param = param_class(name=param_name, description=param_description, value=param_value)
+        setattr(args, param_variable, param)
     return args
 
 
@@ -286,13 +289,14 @@ if __name__ == '__main__':
     actor_module = importlib.import_module(config.CUSTOMIZE_ACTOR_PATH + actor_class_name)
     actor_class = getattr(actor_module, actor_class_name)
     actor = actor_class()
+    # set actor 变量参数
+    params = get_actor_params(actor, actor_json)
+    actor.set_args(params)
     # TODO get_set_param,get_set_runtime_param
     input_ports = get_actor_input_ports(actor, actor_json)
     output_ports = get_actor_output_ports(actor, actor_json)
-    params = get_actor_params(actor, actor_json)
-    actor.input_ports = input_ports
-    actor.output_ports = output_ports
-    actor.args = params
+    actor.set_input_ports(input_ports)
+    actor.set_output_ports(output_ports)
     # 设置actor状态为已开始
     actor_ready()
     current_actor_state = actor_constant.ACTOR_STATE_READY
